@@ -36,7 +36,6 @@
 #include <qscrollbar.h>
 
 #include <QDebug>
-#include <klocale.h>
 
 #include <cmath>
 #include <algorithm>
@@ -47,7 +46,7 @@ KigWidget::KigWidget( KigPart* part,
                       QWidget* parent,
                       bool fullscreen )
   : QWidget( parent,
-             fullscreen ? Qt::FramelessWindowHint : (Qt::WFlags)0 ),
+             fullscreen ? Qt::FramelessWindowHint : Qt::Widget ),
     mpart( part ),
     mview( view ),
     stillPix(size()),
